tsseg.algorithms.patss.algorithms package
=========================================

Submodules
----------

tsseg.algorithms.patss.algorithms.ClaSP module
----------------------------------------------

.. automodule:: tsseg.algorithms.patss.algorithms.ClaSP
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.patss.algorithms.FLOSS module
----------------------------------------------

.. automodule:: tsseg.algorithms.patss.algorithms.FLOSS
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.patss.algorithms.PaTSS module
----------------------------------------------

.. automodule:: tsseg.algorithms.patss.algorithms.PaTSS
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.patss.algorithms.PaTSS\_perso module
-----------------------------------------------------

.. automodule:: tsseg.algorithms.patss.algorithms.PaTSS_perso
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.patss.algorithms
   :members:
   :show-inheritance:
   :undoc-members:
